Documentation
¶
Index ¶
- Constants
- Variables
- func RegisterAddressServer(s grpc.ServiceRegistrar, srv AddressServer)
- func RegisterUserServer(s grpc.ServiceRegistrar, srv UserServer)
- type AddressClient
- type AddressInfo
- func (*AddressInfo) Descriptor() ([]byte, []int)deprecated
- func (x *AddressInfo) GetAddress() string
- func (x *AddressInfo) GetCity() string
- func (x *AddressInfo) GetCounty() string
- func (x *AddressInfo) GetID() int64
- func (x *AddressInfo) GetIsDefault() bool
- func (x *AddressInfo) GetMobile() string
- func (x *AddressInfo) GetName() string
- func (x *AddressInfo) GetProvince() string
- func (x *AddressInfo) GetTownship() string
- func (x *AddressInfo) GetUserId() int64
- func (*AddressInfo) ProtoMessage()
- func (x *AddressInfo) ProtoReflect() protoreflect.Message
- func (x *AddressInfo) Reset()
- func (x *AddressInfo) String() string
- type AddressListRequest
- type AddressListResponse
- func (*AddressListResponse) Descriptor() ([]byte, []int)deprecated
- func (x *AddressListResponse) GetInfo() []*AddressInfo
- func (*AddressListResponse) ProtoMessage()
- func (x *AddressListResponse) ProtoReflect() protoreflect.Message
- func (x *AddressListResponse) Reset()
- func (x *AddressListResponse) String() string
- type AddressServer
- type CreateAddPwdResponse
- func (*CreateAddPwdResponse) Descriptor() ([]byte, []int)deprecated
- func (x *CreateAddPwdResponse) GetInfo() *AddressInfo
- func (*CreateAddPwdResponse) ProtoMessage()
- func (x *CreateAddPwdResponse) ProtoReflect() protoreflect.Message
- func (x *CreateAddPwdResponse) Reset()
- func (x *CreateAddPwdResponse) String() string
- type CreateAddRequest
- type CreateHistoryRequest
- func (*CreateHistoryRequest) Descriptor() ([]byte, []int)deprecated
- func (x *CreateHistoryRequest) GetInfo() *HistoryInfo
- func (*CreateHistoryRequest) ProtoMessage()
- func (x *CreateHistoryRequest) ProtoReflect() protoreflect.Message
- func (x *CreateHistoryRequest) Reset()
- func (x *CreateHistoryRequest) String() string
- type CreateHistoryResponse
- func (*CreateHistoryResponse) Descriptor() ([]byte, []int)deprecated
- func (x *CreateHistoryResponse) GetInfo() *HistoryInfo
- func (*CreateHistoryResponse) ProtoMessage()
- func (x *CreateHistoryResponse) ProtoReflect() protoreflect.Message
- func (x *CreateHistoryResponse) Reset()
- func (x *CreateHistoryResponse) String() string
- type CreatePointRecordRequest
- func (*CreatePointRecordRequest) Descriptor() ([]byte, []int)deprecated
- func (x *CreatePointRecordRequest) GetInfo() *PointRecordInfo
- func (*CreatePointRecordRequest) ProtoMessage()
- func (x *CreatePointRecordRequest) ProtoReflect() protoreflect.Message
- func (x *CreatePointRecordRequest) Reset()
- func (x *CreatePointRecordRequest) String() string
- type CreatePointRecordResponse
- func (*CreatePointRecordResponse) Descriptor() ([]byte, []int)deprecated
- func (x *CreatePointRecordResponse) GetInfo() *UserInfo
- func (*CreatePointRecordResponse) ProtoMessage()
- func (x *CreatePointRecordResponse) ProtoReflect() protoreflect.Message
- func (x *CreatePointRecordResponse) Reset()
- func (x *CreatePointRecordResponse) String() string
- type DeleteAddressRequest
- func (*DeleteAddressRequest) Descriptor() ([]byte, []int)deprecated
- func (x *DeleteAddressRequest) GetID() int64
- func (*DeleteAddressRequest) ProtoMessage()
- func (x *DeleteAddressRequest) ProtoReflect() protoreflect.Message
- func (x *DeleteAddressRequest) Reset()
- func (x *DeleteAddressRequest) String() string
- type DeleteAddressResponse
- type DeleteRequest
- type DeleteResponse
- type GetAddressInfoByIDRequest
- func (*GetAddressInfoByIDRequest) Descriptor() ([]byte, []int)deprecated
- func (x *GetAddressInfoByIDRequest) GetID() int64
- func (*GetAddressInfoByIDRequest) ProtoMessage()
- func (x *GetAddressInfoByIDRequest) ProtoReflect() protoreflect.Message
- func (x *GetAddressInfoByIDRequest) Reset()
- func (x *GetAddressInfoByIDRequest) String() string
- type GetAddressInfoByIDResponse
- func (*GetAddressInfoByIDResponse) Descriptor() ([]byte, []int)deprecated
- func (x *GetAddressInfoByIDResponse) GetInfo() *AddressInfo
- func (*GetAddressInfoByIDResponse) ProtoMessage()
- func (x *GetAddressInfoByIDResponse) ProtoReflect() protoreflect.Message
- func (x *GetAddressInfoByIDResponse) Reset()
- func (x *GetAddressInfoByIDResponse) String() string
- type GetDefaultAddrRequest
- func (*GetDefaultAddrRequest) Descriptor() ([]byte, []int)deprecated
- func (x *GetDefaultAddrRequest) GetUserID() int64
- func (*GetDefaultAddrRequest) ProtoMessage()
- func (x *GetDefaultAddrRequest) ProtoReflect() protoreflect.Message
- func (x *GetDefaultAddrRequest) Reset()
- func (x *GetDefaultAddrRequest) String() string
- type GetDefaultAddrResponse
- func (*GetDefaultAddrResponse) Descriptor() ([]byte, []int)deprecated
- func (x *GetDefaultAddrResponse) GetInfo() *AddressInfo
- func (*GetDefaultAddrResponse) ProtoMessage()
- func (x *GetDefaultAddrResponse) ProtoReflect() protoreflect.Message
- func (x *GetDefaultAddrResponse) Reset()
- func (x *GetDefaultAddrResponse) String() string
- type GetInfoByMobileRequest
- func (*GetInfoByMobileRequest) Descriptor() ([]byte, []int)deprecated
- func (x *GetInfoByMobileRequest) GetMobile() string
- func (*GetInfoByMobileRequest) ProtoMessage()
- func (x *GetInfoByMobileRequest) ProtoReflect() protoreflect.Message
- func (x *GetInfoByMobileRequest) Reset()
- func (x *GetInfoByMobileRequest) String() string
- type GetInfoByMobileResponse
- func (*GetInfoByMobileResponse) Descriptor() ([]byte, []int)deprecated
- func (x *GetInfoByMobileResponse) GetInfo() *UserInfo
- func (*GetInfoByMobileResponse) ProtoMessage()
- func (x *GetInfoByMobileResponse) ProtoReflect() protoreflect.Message
- func (x *GetInfoByMobileResponse) Reset()
- func (x *GetInfoByMobileResponse) String() string
- type GetInfoByOpenIDRequest
- func (*GetInfoByOpenIDRequest) Descriptor() ([]byte, []int)deprecated
- func (x *GetInfoByOpenIDRequest) GetOpenId() string
- func (*GetInfoByOpenIDRequest) ProtoMessage()
- func (x *GetInfoByOpenIDRequest) ProtoReflect() protoreflect.Message
- func (x *GetInfoByOpenIDRequest) Reset()
- func (x *GetInfoByOpenIDRequest) String() string
- type GetInfoByOpenIDResponse
- func (*GetInfoByOpenIDResponse) Descriptor() ([]byte, []int)deprecated
- func (x *GetInfoByOpenIDResponse) GetInfo() *UserInfo
- func (*GetInfoByOpenIDResponse) ProtoMessage()
- func (x *GetInfoByOpenIDResponse) ProtoReflect() protoreflect.Message
- func (x *GetInfoByOpenIDResponse) Reset()
- func (x *GetInfoByOpenIDResponse) String() string
- type GetUserInfoRequest
- type GetUserInfoResponse
- func (*GetUserInfoResponse) Descriptor() ([]byte, []int)deprecated
- func (x *GetUserInfoResponse) GetInfo() *UserInfo
- func (*GetUserInfoResponse) ProtoMessage()
- func (x *GetUserInfoResponse) ProtoReflect() protoreflect.Message
- func (x *GetUserInfoResponse) Reset()
- func (x *GetUserInfoResponse) String() string
- type HistoryInfo
- func (*HistoryInfo) Descriptor() ([]byte, []int)deprecated
- func (x *HistoryInfo) GetBrowseDate() string
- func (x *HistoryInfo) GetCover() string
- func (x *HistoryInfo) GetGoodsId() int64
- func (x *HistoryInfo) GetPrice() string
- func (x *HistoryInfo) GetTitle() string
- func (x *HistoryInfo) GetUserId() int64
- func (*HistoryInfo) ProtoMessage()
- func (x *HistoryInfo) ProtoReflect() protoreflect.Message
- func (x *HistoryInfo) Reset()
- func (x *HistoryInfo) String() string
- type PointRecordInfo
- func (*PointRecordInfo) Descriptor() ([]byte, []int)deprecated
- func (x *PointRecordInfo) GetAmount() int64
- func (x *PointRecordInfo) GetBalance() int64
- func (x *PointRecordInfo) GetChangeType() string
- func (x *PointRecordInfo) GetDescription() string
- func (x *PointRecordInfo) GetID() int64
- func (x *PointRecordInfo) GetOperationTime() string
- func (x *PointRecordInfo) GetOrderID() int64
- func (x *PointRecordInfo) GetSource() string
- func (x *PointRecordInfo) GetUserId() int64
- func (*PointRecordInfo) ProtoMessage()
- func (x *PointRecordInfo) ProtoReflect() protoreflect.Message
- func (x *PointRecordInfo) Reset()
- func (x *PointRecordInfo) String() string
- type RegisterRequest
- type RegisterResponse
- type UnimplementedAddressServer
- func (UnimplementedAddressServer) AddressList(context.Context, *AddressListRequest) (*AddressListResponse, error)
- func (UnimplementedAddressServer) CreateAdd(context.Context, *CreateAddRequest) (*CreateAddPwdResponse, error)
- func (UnimplementedAddressServer) DeleteAddress(context.Context, *DeleteAddressRequest) (*DeleteResponse, error)
- func (UnimplementedAddressServer) GetAddressInfoByID(context.Context, *GetAddressInfoByIDRequest) (*GetAddressInfoByIDResponse, error)
- func (UnimplementedAddressServer) GetDefaultAddr(context.Context, *GetDefaultAddrRequest) (*GetDefaultAddrResponse, error)
- func (UnimplementedAddressServer) UpdateAddress(context.Context, *UpdateAddressRequest) (*UpdateAddressResponse, error)
- func (UnimplementedAddressServer) UpdateDefaultAddr(context.Context, *UpdateDefaultAddrRequest) (*UpdateDefaultAddrResponse, error)
- type UnimplementedUserServer
- func (UnimplementedUserServer) CreateHistory(context.Context, *CreateHistoryRequest) (*CreateHistoryResponse, error)
- func (UnimplementedUserServer) CreatePointRecord(context.Context, *CreatePointRecordRequest) (*CreatePointRecordResponse, error)
- func (UnimplementedUserServer) Delete(context.Context, *DeleteRequest) (*DeleteResponse, error)
- func (UnimplementedUserServer) GetInfoByMobile(context.Context, *GetInfoByMobileRequest) (*GetInfoByMobileResponse, error)
- func (UnimplementedUserServer) GetInfoByOpenID(context.Context, *GetInfoByOpenIDRequest) (*GetInfoByOpenIDResponse, error)
- func (UnimplementedUserServer) GetUserInfo(context.Context, *GetUserInfoRequest) (*GetUserInfoResponse, error)
- func (UnimplementedUserServer) Register(context.Context, *RegisterRequest) (*RegisterResponse, error)
- func (UnimplementedUserServer) Update(context.Context, *UpdateRequest) (*UpdateResponse, error)
- func (UnimplementedUserServer) UpdateMobile(context.Context, *UpdateMobileRequest) (*UpdateMobileResponse, error)
- func (UnimplementedUserServer) UpdatePwd(context.Context, *UpdatePwdRequest) (*UpdatePwdResponse, error)
- type UnsafeAddressServer
- type UnsafeUserServer
- type UpdateAddressRequest
- func (*UpdateAddressRequest) Descriptor() ([]byte, []int)deprecated
- func (x *UpdateAddressRequest) GetID() int64
- func (x *UpdateAddressRequest) GetInfo() *AddressInfo
- func (*UpdateAddressRequest) ProtoMessage()
- func (x *UpdateAddressRequest) ProtoReflect() protoreflect.Message
- func (x *UpdateAddressRequest) Reset()
- func (x *UpdateAddressRequest) String() string
- type UpdateAddressResponse
- type UpdateDefaultAddrRequest
- func (*UpdateDefaultAddrRequest) Descriptor() ([]byte, []int)deprecated
- func (x *UpdateDefaultAddrRequest) GetID() int64
- func (x *UpdateDefaultAddrRequest) GetUserID() int64
- func (*UpdateDefaultAddrRequest) ProtoMessage()
- func (x *UpdateDefaultAddrRequest) ProtoReflect() protoreflect.Message
- func (x *UpdateDefaultAddrRequest) Reset()
- func (x *UpdateDefaultAddrRequest) String() string
- type UpdateDefaultAddrResponse
- type UpdateMobileRequest
- func (*UpdateMobileRequest) Descriptor() ([]byte, []int)deprecated
- func (x *UpdateMobileRequest) GetID() int64
- func (x *UpdateMobileRequest) GetMobile() string
- func (*UpdateMobileRequest) ProtoMessage()
- func (x *UpdateMobileRequest) ProtoReflect() protoreflect.Message
- func (x *UpdateMobileRequest) Reset()
- func (x *UpdateMobileRequest) String() string
- type UpdateMobileResponse
- type UpdatePwdRequest
- func (*UpdatePwdRequest) Descriptor() ([]byte, []int)deprecated
- func (x *UpdatePwdRequest) GetMobile() string
- func (x *UpdatePwdRequest) GetPassword() string
- func (*UpdatePwdRequest) ProtoMessage()
- func (x *UpdatePwdRequest) ProtoReflect() protoreflect.Message
- func (x *UpdatePwdRequest) Reset()
- func (x *UpdatePwdRequest) String() string
- type UpdatePwdResponse
- type UpdateRequest
- func (*UpdateRequest) Descriptor() ([]byte, []int)deprecated
- func (x *UpdateRequest) GetID() int64
- func (x *UpdateRequest) GetInfo() *UserInfo
- func (*UpdateRequest) ProtoMessage()
- func (x *UpdateRequest) ProtoReflect() protoreflect.Message
- func (x *UpdateRequest) Reset()
- func (x *UpdateRequest) String() string
- type UpdateResponse
- type UserClient
- type UserInfo
- func (*UserInfo) Descriptor() ([]byte, []int)deprecated
- func (x *UserInfo) GetAvatar() string
- func (x *UserInfo) GetBirthday() string
- func (x *UserInfo) GetEmail() string
- func (x *UserInfo) GetID() int64
- func (x *UserInfo) GetLoginSource() string
- func (x *UserInfo) GetMobile() string
- func (x *UserInfo) GetNickname() string
- func (x *UserInfo) GetOpenid() string
- func (x *UserInfo) GetPassword() string
- func (x *UserInfo) GetPoints() int64
- func (x *UserInfo) GetSalt() string
- func (x *UserInfo) GetSex() int64
- func (x *UserInfo) GetUnionid() string
- func (*UserInfo) ProtoMessage()
- func (x *UserInfo) ProtoReflect() protoreflect.Message
- func (x *UserInfo) Reset()
- func (x *UserInfo) String() string
- type UserServer
Constants ¶
const ( User_GetInfoByMobile_FullMethodName = "/user.User/GetInfoByMobile" User_Register_FullMethodName = "/user.User/Register" User_Delete_FullMethodName = "/user.User/Delete" User_Update_FullMethodName = "/user.User/Update" User_UpdatePwd_FullMethodName = "/user.User/UpdatePwd" User_UpdateMobile_FullMethodName = "/user.User/UpdateMobile" User_GetUserInfo_FullMethodName = "/user.User/GetUserInfo" User_GetInfoByOpenID_FullMethodName = "/user.User/GetInfoByOpenID" User_CreateHistory_FullMethodName = "/user.User/CreateHistory" User_CreatePointRecord_FullMethodName = "/user.User/CreatePointRecord" )
const ( Address_CreateAdd_FullMethodName = "/user.Address/CreateAdd" Address_DeleteAddress_FullMethodName = "/user.Address/DeleteAddress" Address_UpdateAddress_FullMethodName = "/user.Address/UpdateAddress" Address_AddressList_FullMethodName = "/user.Address/AddressList" Address_UpdateDefaultAddr_FullMethodName = "/user.Address/UpdateDefaultAddr" Address_GetAddressInfoByID_FullMethodName = "/user.Address/GetAddressInfoByID" Address_GetDefaultAddr_FullMethodName = "/user.Address/GetDefaultAddr" )
Variables ¶
var Address_ServiceDesc = grpc.ServiceDesc{ ServiceName: "user.Address", HandlerType: (*AddressServer)(nil), Methods: []grpc.MethodDesc{ { MethodName: "CreateAdd", Handler: _Address_CreateAdd_Handler, }, { MethodName: "DeleteAddress", Handler: _Address_DeleteAddress_Handler, }, { MethodName: "UpdateAddress", Handler: _Address_UpdateAddress_Handler, }, { MethodName: "AddressList", Handler: _Address_AddressList_Handler, }, { MethodName: "UpdateDefaultAddr", Handler: _Address_UpdateDefaultAddr_Handler, }, { MethodName: "GetAddressInfoByID", Handler: _Address_GetAddressInfoByID_Handler, }, { MethodName: "GetDefaultAddr", Handler: _Address_GetDefaultAddr_Handler, }, }, Streams: []grpc.StreamDesc{}, Metadata: "user.proto", }
Address_ServiceDesc is the grpc.ServiceDesc for Address service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)
var File_user_proto protoreflect.FileDescriptor
var User_ServiceDesc = grpc.ServiceDesc{ ServiceName: "user.User", HandlerType: (*UserServer)(nil), Methods: []grpc.MethodDesc{ { MethodName: "GetInfoByMobile", Handler: _User_GetInfoByMobile_Handler, }, { MethodName: "Register", Handler: _User_Register_Handler, }, { MethodName: "Delete", Handler: _User_Delete_Handler, }, { MethodName: "Update", Handler: _User_Update_Handler, }, { MethodName: "UpdatePwd", Handler: _User_UpdatePwd_Handler, }, { MethodName: "UpdateMobile", Handler: _User_UpdateMobile_Handler, }, { MethodName: "GetUserInfo", Handler: _User_GetUserInfo_Handler, }, { MethodName: "GetInfoByOpenID", Handler: _User_GetInfoByOpenID_Handler, }, { MethodName: "CreateHistory", Handler: _User_CreateHistory_Handler, }, { MethodName: "CreatePointRecord", Handler: _User_CreatePointRecord_Handler, }, }, Streams: []grpc.StreamDesc{}, Metadata: "user.proto", }
User_ServiceDesc is the grpc.ServiceDesc for User service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)
Functions ¶
func RegisterAddressServer ¶
func RegisterAddressServer(s grpc.ServiceRegistrar, srv AddressServer)
func RegisterUserServer ¶
func RegisterUserServer(s grpc.ServiceRegistrar, srv UserServer)
Types ¶
type AddressClient ¶
type AddressClient interface {
CreateAdd(ctx context.Context, in *CreateAddRequest, opts ...grpc.CallOption) (*CreateAddPwdResponse, error)
DeleteAddress(ctx context.Context, in *DeleteAddressRequest, opts ...grpc.CallOption) (*DeleteResponse, error)
UpdateAddress(ctx context.Context, in *UpdateAddressRequest, opts ...grpc.CallOption) (*UpdateAddressResponse, error)
AddressList(ctx context.Context, in *AddressListRequest, opts ...grpc.CallOption) (*AddressListResponse, error)
UpdateDefaultAddr(ctx context.Context, in *UpdateDefaultAddrRequest, opts ...grpc.CallOption) (*UpdateDefaultAddrResponse, error)
GetAddressInfoByID(ctx context.Context, in *GetAddressInfoByIDRequest, opts ...grpc.CallOption) (*GetAddressInfoByIDResponse, error)
GetDefaultAddr(ctx context.Context, in *GetDefaultAddrRequest, opts ...grpc.CallOption) (*GetDefaultAddrResponse, error)
}
AddressClient is the client API for Address service.
For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.
func NewAddressClient ¶
func NewAddressClient(cc grpc.ClientConnInterface) AddressClient
type AddressInfo ¶
type AddressInfo struct {
ID int64 `protobuf:"varint,1,opt,name=ID,proto3" json:"ID,omitempty"`
UserId int64 `protobuf:"varint,10,opt,name=UserId,proto3" json:"UserId,omitempty"`
Name string `protobuf:"bytes,20,opt,name=Name,proto3" json:"Name,omitempty"`
Mobile string `protobuf:"bytes,30,opt,name=Mobile,proto3" json:"Mobile,omitempty"`
Province string `protobuf:"bytes,40,opt,name=Province,proto3" json:"Province,omitempty"`
City string `protobuf:"bytes,50,opt,name=City,proto3" json:"City,omitempty"`
County string `protobuf:"bytes,60,opt,name=County,proto3" json:"County,omitempty"`
Township string `protobuf:"bytes,70,opt,name=Township,proto3" json:"Township,omitempty"`
Address string `protobuf:"bytes,80,opt,name=Address,proto3" json:"Address,omitempty"`
IsDefault bool `protobuf:"varint,90,opt,name=IsDefault,proto3" json:"IsDefault,omitempty"`
// contains filtered or unexported fields
}
func (*AddressInfo) Descriptor
deprecated
func (*AddressInfo) Descriptor() ([]byte, []int)
Deprecated: Use AddressInfo.ProtoReflect.Descriptor instead.
func (*AddressInfo) GetAddress ¶
func (x *AddressInfo) GetAddress() string
func (*AddressInfo) GetCity ¶
func (x *AddressInfo) GetCity() string
func (*AddressInfo) GetCounty ¶
func (x *AddressInfo) GetCounty() string
func (*AddressInfo) GetID ¶
func (x *AddressInfo) GetID() int64
func (*AddressInfo) GetIsDefault ¶
func (x *AddressInfo) GetIsDefault() bool
func (*AddressInfo) GetMobile ¶
func (x *AddressInfo) GetMobile() string
func (*AddressInfo) GetName ¶
func (x *AddressInfo) GetName() string
func (*AddressInfo) GetProvince ¶
func (x *AddressInfo) GetProvince() string
func (*AddressInfo) GetTownship ¶
func (x *AddressInfo) GetTownship() string
func (*AddressInfo) GetUserId ¶
func (x *AddressInfo) GetUserId() int64
func (*AddressInfo) ProtoMessage ¶
func (*AddressInfo) ProtoMessage()
func (*AddressInfo) ProtoReflect ¶
func (x *AddressInfo) ProtoReflect() protoreflect.Message
func (*AddressInfo) Reset ¶
func (x *AddressInfo) Reset()
func (*AddressInfo) String ¶
func (x *AddressInfo) String() string
type AddressListRequest ¶
type AddressListRequest struct {
// contains filtered or unexported fields
}
func (*AddressListRequest) Descriptor
deprecated
func (*AddressListRequest) Descriptor() ([]byte, []int)
Deprecated: Use AddressListRequest.ProtoReflect.Descriptor instead.
func (*AddressListRequest) ProtoMessage ¶
func (*AddressListRequest) ProtoMessage()
func (*AddressListRequest) ProtoReflect ¶
func (x *AddressListRequest) ProtoReflect() protoreflect.Message
func (*AddressListRequest) Reset ¶
func (x *AddressListRequest) Reset()
func (*AddressListRequest) String ¶
func (x *AddressListRequest) String() string
type AddressListResponse ¶
type AddressListResponse struct {
Info []*AddressInfo `protobuf:"bytes,10,rep,name=Info,proto3" json:"Info,omitempty"`
// contains filtered or unexported fields
}
func (*AddressListResponse) Descriptor
deprecated
func (*AddressListResponse) Descriptor() ([]byte, []int)
Deprecated: Use AddressListResponse.ProtoReflect.Descriptor instead.
func (*AddressListResponse) GetInfo ¶
func (x *AddressListResponse) GetInfo() []*AddressInfo
func (*AddressListResponse) ProtoMessage ¶
func (*AddressListResponse) ProtoMessage()
func (*AddressListResponse) ProtoReflect ¶
func (x *AddressListResponse) ProtoReflect() protoreflect.Message
func (*AddressListResponse) Reset ¶
func (x *AddressListResponse) Reset()
func (*AddressListResponse) String ¶
func (x *AddressListResponse) String() string
type AddressServer ¶
type AddressServer interface {
CreateAdd(context.Context, *CreateAddRequest) (*CreateAddPwdResponse, error)
DeleteAddress(context.Context, *DeleteAddressRequest) (*DeleteResponse, error)
UpdateAddress(context.Context, *UpdateAddressRequest) (*UpdateAddressResponse, error)
AddressList(context.Context, *AddressListRequest) (*AddressListResponse, error)
UpdateDefaultAddr(context.Context, *UpdateDefaultAddrRequest) (*UpdateDefaultAddrResponse, error)
GetAddressInfoByID(context.Context, *GetAddressInfoByIDRequest) (*GetAddressInfoByIDResponse, error)
GetDefaultAddr(context.Context, *GetDefaultAddrRequest) (*GetDefaultAddrResponse, error)
// contains filtered or unexported methods
}
AddressServer is the server API for Address service. All implementations must embed UnimplementedAddressServer for forward compatibility
type CreateAddPwdResponse ¶
type CreateAddPwdResponse struct {
Info *AddressInfo `protobuf:"bytes,10,opt,name=Info,proto3" json:"Info,omitempty"`
// contains filtered or unexported fields
}
func (*CreateAddPwdResponse) Descriptor
deprecated
func (*CreateAddPwdResponse) Descriptor() ([]byte, []int)
Deprecated: Use CreateAddPwdResponse.ProtoReflect.Descriptor instead.
func (*CreateAddPwdResponse) GetInfo ¶
func (x *CreateAddPwdResponse) GetInfo() *AddressInfo
func (*CreateAddPwdResponse) ProtoMessage ¶
func (*CreateAddPwdResponse) ProtoMessage()
func (*CreateAddPwdResponse) ProtoReflect ¶
func (x *CreateAddPwdResponse) ProtoReflect() protoreflect.Message
func (*CreateAddPwdResponse) Reset ¶
func (x *CreateAddPwdResponse) Reset()
func (*CreateAddPwdResponse) String ¶
func (x *CreateAddPwdResponse) String() string
type CreateAddRequest ¶
type CreateAddRequest struct {
Info *AddressInfo `protobuf:"bytes,10,opt,name=Info,proto3" json:"Info,omitempty"`
// contains filtered or unexported fields
}
func (*CreateAddRequest) Descriptor
deprecated
func (*CreateAddRequest) Descriptor() ([]byte, []int)
Deprecated: Use CreateAddRequest.ProtoReflect.Descriptor instead.
func (*CreateAddRequest) GetInfo ¶
func (x *CreateAddRequest) GetInfo() *AddressInfo
func (*CreateAddRequest) ProtoMessage ¶
func (*CreateAddRequest) ProtoMessage()
func (*CreateAddRequest) ProtoReflect ¶
func (x *CreateAddRequest) ProtoReflect() protoreflect.Message
func (*CreateAddRequest) Reset ¶
func (x *CreateAddRequest) Reset()
func (*CreateAddRequest) String ¶
func (x *CreateAddRequest) String() string
type CreateHistoryRequest ¶
type CreateHistoryRequest struct {
Info *HistoryInfo `protobuf:"bytes,10,opt,name=Info,proto3" json:"Info,omitempty"`
// contains filtered or unexported fields
}
func (*CreateHistoryRequest) Descriptor
deprecated
func (*CreateHistoryRequest) Descriptor() ([]byte, []int)
Deprecated: Use CreateHistoryRequest.ProtoReflect.Descriptor instead.
func (*CreateHistoryRequest) GetInfo ¶
func (x *CreateHistoryRequest) GetInfo() *HistoryInfo
func (*CreateHistoryRequest) ProtoMessage ¶
func (*CreateHistoryRequest) ProtoMessage()
func (*CreateHistoryRequest) ProtoReflect ¶
func (x *CreateHistoryRequest) ProtoReflect() protoreflect.Message
func (*CreateHistoryRequest) Reset ¶
func (x *CreateHistoryRequest) Reset()
func (*CreateHistoryRequest) String ¶
func (x *CreateHistoryRequest) String() string
type CreateHistoryResponse ¶
type CreateHistoryResponse struct {
Info *HistoryInfo `protobuf:"bytes,10,opt,name=Info,proto3" json:"Info,omitempty"`
// contains filtered or unexported fields
}
func (*CreateHistoryResponse) Descriptor
deprecated
func (*CreateHistoryResponse) Descriptor() ([]byte, []int)
Deprecated: Use CreateHistoryResponse.ProtoReflect.Descriptor instead.
func (*CreateHistoryResponse) GetInfo ¶
func (x *CreateHistoryResponse) GetInfo() *HistoryInfo
func (*CreateHistoryResponse) ProtoMessage ¶
func (*CreateHistoryResponse) ProtoMessage()
func (*CreateHistoryResponse) ProtoReflect ¶
func (x *CreateHistoryResponse) ProtoReflect() protoreflect.Message
func (*CreateHistoryResponse) Reset ¶
func (x *CreateHistoryResponse) Reset()
func (*CreateHistoryResponse) String ¶
func (x *CreateHistoryResponse) String() string
type CreatePointRecordRequest ¶
type CreatePointRecordRequest struct {
Info *PointRecordInfo `protobuf:"bytes,10,opt,name=Info,proto3" json:"Info,omitempty"`
// contains filtered or unexported fields
}
func (*CreatePointRecordRequest) Descriptor
deprecated
func (*CreatePointRecordRequest) Descriptor() ([]byte, []int)
Deprecated: Use CreatePointRecordRequest.ProtoReflect.Descriptor instead.
func (*CreatePointRecordRequest) GetInfo ¶
func (x *CreatePointRecordRequest) GetInfo() *PointRecordInfo
func (*CreatePointRecordRequest) ProtoMessage ¶
func (*CreatePointRecordRequest) ProtoMessage()
func (*CreatePointRecordRequest) ProtoReflect ¶
func (x *CreatePointRecordRequest) ProtoReflect() protoreflect.Message
func (*CreatePointRecordRequest) Reset ¶
func (x *CreatePointRecordRequest) Reset()
func (*CreatePointRecordRequest) String ¶
func (x *CreatePointRecordRequest) String() string
type CreatePointRecordResponse ¶
type CreatePointRecordResponse struct {
Info *UserInfo `protobuf:"bytes,10,opt,name=Info,proto3" json:"Info,omitempty"`
// contains filtered or unexported fields
}
func (*CreatePointRecordResponse) Descriptor
deprecated
func (*CreatePointRecordResponse) Descriptor() ([]byte, []int)
Deprecated: Use CreatePointRecordResponse.ProtoReflect.Descriptor instead.
func (*CreatePointRecordResponse) GetInfo ¶
func (x *CreatePointRecordResponse) GetInfo() *UserInfo
func (*CreatePointRecordResponse) ProtoMessage ¶
func (*CreatePointRecordResponse) ProtoMessage()
func (*CreatePointRecordResponse) ProtoReflect ¶
func (x *CreatePointRecordResponse) ProtoReflect() protoreflect.Message
func (*CreatePointRecordResponse) Reset ¶
func (x *CreatePointRecordResponse) Reset()
func (*CreatePointRecordResponse) String ¶
func (x *CreatePointRecordResponse) String() string
type DeleteAddressRequest ¶
type DeleteAddressRequest struct {
ID int64 `protobuf:"varint,10,opt,name=ID,proto3" json:"ID,omitempty"`
// contains filtered or unexported fields
}
func (*DeleteAddressRequest) Descriptor
deprecated
func (*DeleteAddressRequest) Descriptor() ([]byte, []int)
Deprecated: Use DeleteAddressRequest.ProtoReflect.Descriptor instead.
func (*DeleteAddressRequest) GetID ¶
func (x *DeleteAddressRequest) GetID() int64
func (*DeleteAddressRequest) ProtoMessage ¶
func (*DeleteAddressRequest) ProtoMessage()
func (*DeleteAddressRequest) ProtoReflect ¶
func (x *DeleteAddressRequest) ProtoReflect() protoreflect.Message
func (*DeleteAddressRequest) Reset ¶
func (x *DeleteAddressRequest) Reset()
func (*DeleteAddressRequest) String ¶
func (x *DeleteAddressRequest) String() string
type DeleteAddressResponse ¶
type DeleteAddressResponse struct {
// contains filtered or unexported fields
}
func (*DeleteAddressResponse) Descriptor
deprecated
func (*DeleteAddressResponse) Descriptor() ([]byte, []int)
Deprecated: Use DeleteAddressResponse.ProtoReflect.Descriptor instead.
func (*DeleteAddressResponse) ProtoMessage ¶
func (*DeleteAddressResponse) ProtoMessage()
func (*DeleteAddressResponse) ProtoReflect ¶
func (x *DeleteAddressResponse) ProtoReflect() protoreflect.Message
func (*DeleteAddressResponse) Reset ¶
func (x *DeleteAddressResponse) Reset()
func (*DeleteAddressResponse) String ¶
func (x *DeleteAddressResponse) String() string
type DeleteRequest ¶
type DeleteRequest struct {
ID int64 `protobuf:"varint,1,opt,name=ID,proto3" json:"ID,omitempty"`
// contains filtered or unexported fields
}
func (*DeleteRequest) Descriptor
deprecated
func (*DeleteRequest) Descriptor() ([]byte, []int)
Deprecated: Use DeleteRequest.ProtoReflect.Descriptor instead.
func (*DeleteRequest) GetID ¶
func (x *DeleteRequest) GetID() int64
func (*DeleteRequest) ProtoMessage ¶
func (*DeleteRequest) ProtoMessage()
func (*DeleteRequest) ProtoReflect ¶
func (x *DeleteRequest) ProtoReflect() protoreflect.Message
func (*DeleteRequest) Reset ¶
func (x *DeleteRequest) Reset()
func (*DeleteRequest) String ¶
func (x *DeleteRequest) String() string
type DeleteResponse ¶
type DeleteResponse struct {
// contains filtered or unexported fields
}
func (*DeleteResponse) Descriptor
deprecated
func (*DeleteResponse) Descriptor() ([]byte, []int)
Deprecated: Use DeleteResponse.ProtoReflect.Descriptor instead.
func (*DeleteResponse) ProtoMessage ¶
func (*DeleteResponse) ProtoMessage()
func (*DeleteResponse) ProtoReflect ¶
func (x *DeleteResponse) ProtoReflect() protoreflect.Message
func (*DeleteResponse) Reset ¶
func (x *DeleteResponse) Reset()
func (*DeleteResponse) String ¶
func (x *DeleteResponse) String() string
type GetAddressInfoByIDRequest ¶
type GetAddressInfoByIDRequest struct {
ID int64 `protobuf:"varint,10,opt,name=ID,proto3" json:"ID,omitempty"`
// contains filtered or unexported fields
}
func (*GetAddressInfoByIDRequest) Descriptor
deprecated
func (*GetAddressInfoByIDRequest) Descriptor() ([]byte, []int)
Deprecated: Use GetAddressInfoByIDRequest.ProtoReflect.Descriptor instead.
func (*GetAddressInfoByIDRequest) GetID ¶
func (x *GetAddressInfoByIDRequest) GetID() int64
func (*GetAddressInfoByIDRequest) ProtoMessage ¶
func (*GetAddressInfoByIDRequest) ProtoMessage()
func (*GetAddressInfoByIDRequest) ProtoReflect ¶
func (x *GetAddressInfoByIDRequest) ProtoReflect() protoreflect.Message
func (*GetAddressInfoByIDRequest) Reset ¶
func (x *GetAddressInfoByIDRequest) Reset()
func (*GetAddressInfoByIDRequest) String ¶
func (x *GetAddressInfoByIDRequest) String() string
type GetAddressInfoByIDResponse ¶
type GetAddressInfoByIDResponse struct {
Info *AddressInfo `protobuf:"bytes,1,opt,name=Info,proto3" json:"Info,omitempty"`
// contains filtered or unexported fields
}
func (*GetAddressInfoByIDResponse) Descriptor
deprecated
func (*GetAddressInfoByIDResponse) Descriptor() ([]byte, []int)
Deprecated: Use GetAddressInfoByIDResponse.ProtoReflect.Descriptor instead.
func (*GetAddressInfoByIDResponse) GetInfo ¶
func (x *GetAddressInfoByIDResponse) GetInfo() *AddressInfo
func (*GetAddressInfoByIDResponse) ProtoMessage ¶
func (*GetAddressInfoByIDResponse) ProtoMessage()
func (*GetAddressInfoByIDResponse) ProtoReflect ¶
func (x *GetAddressInfoByIDResponse) ProtoReflect() protoreflect.Message
func (*GetAddressInfoByIDResponse) Reset ¶
func (x *GetAddressInfoByIDResponse) Reset()
func (*GetAddressInfoByIDResponse) String ¶
func (x *GetAddressInfoByIDResponse) String() string
type GetDefaultAddrRequest ¶
type GetDefaultAddrRequest struct {
UserID int64 `protobuf:"varint,10,opt,name=UserID,proto3" json:"UserID,omitempty"`
// contains filtered or unexported fields
}
func (*GetDefaultAddrRequest) Descriptor
deprecated
func (*GetDefaultAddrRequest) Descriptor() ([]byte, []int)
Deprecated: Use GetDefaultAddrRequest.ProtoReflect.Descriptor instead.
func (*GetDefaultAddrRequest) GetUserID ¶
func (x *GetDefaultAddrRequest) GetUserID() int64
func (*GetDefaultAddrRequest) ProtoMessage ¶
func (*GetDefaultAddrRequest) ProtoMessage()
func (*GetDefaultAddrRequest) ProtoReflect ¶
func (x *GetDefaultAddrRequest) ProtoReflect() protoreflect.Message
func (*GetDefaultAddrRequest) Reset ¶
func (x *GetDefaultAddrRequest) Reset()
func (*GetDefaultAddrRequest) String ¶
func (x *GetDefaultAddrRequest) String() string
type GetDefaultAddrResponse ¶
type GetDefaultAddrResponse struct {
Info *AddressInfo `protobuf:"bytes,1,opt,name=Info,proto3" json:"Info,omitempty"`
// contains filtered or unexported fields
}
func (*GetDefaultAddrResponse) Descriptor
deprecated
func (*GetDefaultAddrResponse) Descriptor() ([]byte, []int)
Deprecated: Use GetDefaultAddrResponse.ProtoReflect.Descriptor instead.
func (*GetDefaultAddrResponse) GetInfo ¶
func (x *GetDefaultAddrResponse) GetInfo() *AddressInfo
func (*GetDefaultAddrResponse) ProtoMessage ¶
func (*GetDefaultAddrResponse) ProtoMessage()
func (*GetDefaultAddrResponse) ProtoReflect ¶
func (x *GetDefaultAddrResponse) ProtoReflect() protoreflect.Message
func (*GetDefaultAddrResponse) Reset ¶
func (x *GetDefaultAddrResponse) Reset()
func (*GetDefaultAddrResponse) String ¶
func (x *GetDefaultAddrResponse) String() string
type GetInfoByMobileRequest ¶
type GetInfoByMobileRequest struct {
Mobile string `protobuf:"bytes,1,opt,name=Mobile,proto3" json:"Mobile,omitempty"`
// contains filtered or unexported fields
}
func (*GetInfoByMobileRequest) Descriptor
deprecated
func (*GetInfoByMobileRequest) Descriptor() ([]byte, []int)
Deprecated: Use GetInfoByMobileRequest.ProtoReflect.Descriptor instead.
func (*GetInfoByMobileRequest) GetMobile ¶
func (x *GetInfoByMobileRequest) GetMobile() string
func (*GetInfoByMobileRequest) ProtoMessage ¶
func (*GetInfoByMobileRequest) ProtoMessage()
func (*GetInfoByMobileRequest) ProtoReflect ¶
func (x *GetInfoByMobileRequest) ProtoReflect() protoreflect.Message
func (*GetInfoByMobileRequest) Reset ¶
func (x *GetInfoByMobileRequest) Reset()
func (*GetInfoByMobileRequest) String ¶
func (x *GetInfoByMobileRequest) String() string
type GetInfoByMobileResponse ¶
type GetInfoByMobileResponse struct {
Info *UserInfo `protobuf:"bytes,1,opt,name=Info,proto3" json:"Info,omitempty"`
// contains filtered or unexported fields
}
func (*GetInfoByMobileResponse) Descriptor
deprecated
func (*GetInfoByMobileResponse) Descriptor() ([]byte, []int)
Deprecated: Use GetInfoByMobileResponse.ProtoReflect.Descriptor instead.
func (*GetInfoByMobileResponse) GetInfo ¶
func (x *GetInfoByMobileResponse) GetInfo() *UserInfo
func (*GetInfoByMobileResponse) ProtoMessage ¶
func (*GetInfoByMobileResponse) ProtoMessage()
func (*GetInfoByMobileResponse) ProtoReflect ¶
func (x *GetInfoByMobileResponse) ProtoReflect() protoreflect.Message
func (*GetInfoByMobileResponse) Reset ¶
func (x *GetInfoByMobileResponse) Reset()
func (*GetInfoByMobileResponse) String ¶
func (x *GetInfoByMobileResponse) String() string
type GetInfoByOpenIDRequest ¶
type GetInfoByOpenIDRequest struct {
OpenId string `protobuf:"bytes,1,opt,name=OpenId,proto3" json:"OpenId,omitempty"`
// contains filtered or unexported fields
}
func (*GetInfoByOpenIDRequest) Descriptor
deprecated
func (*GetInfoByOpenIDRequest) Descriptor() ([]byte, []int)
Deprecated: Use GetInfoByOpenIDRequest.ProtoReflect.Descriptor instead.
func (*GetInfoByOpenIDRequest) GetOpenId ¶
func (x *GetInfoByOpenIDRequest) GetOpenId() string
func (*GetInfoByOpenIDRequest) ProtoMessage ¶
func (*GetInfoByOpenIDRequest) ProtoMessage()
func (*GetInfoByOpenIDRequest) ProtoReflect ¶
func (x *GetInfoByOpenIDRequest) ProtoReflect() protoreflect.Message
func (*GetInfoByOpenIDRequest) Reset ¶
func (x *GetInfoByOpenIDRequest) Reset()
func (*GetInfoByOpenIDRequest) String ¶
func (x *GetInfoByOpenIDRequest) String() string
type GetInfoByOpenIDResponse ¶
type GetInfoByOpenIDResponse struct {
Info *UserInfo `protobuf:"bytes,1,opt,name=Info,proto3" json:"Info,omitempty"`
// contains filtered or unexported fields
}
func (*GetInfoByOpenIDResponse) Descriptor
deprecated
func (*GetInfoByOpenIDResponse) Descriptor() ([]byte, []int)
Deprecated: Use GetInfoByOpenIDResponse.ProtoReflect.Descriptor instead.
func (*GetInfoByOpenIDResponse) GetInfo ¶
func (x *GetInfoByOpenIDResponse) GetInfo() *UserInfo
func (*GetInfoByOpenIDResponse) ProtoMessage ¶
func (*GetInfoByOpenIDResponse) ProtoMessage()
func (*GetInfoByOpenIDResponse) ProtoReflect ¶
func (x *GetInfoByOpenIDResponse) ProtoReflect() protoreflect.Message
func (*GetInfoByOpenIDResponse) Reset ¶
func (x *GetInfoByOpenIDResponse) Reset()
func (*GetInfoByOpenIDResponse) String ¶
func (x *GetInfoByOpenIDResponse) String() string
type GetUserInfoRequest ¶
type GetUserInfoRequest struct {
ID int64 `protobuf:"varint,1,opt,name=ID,proto3" json:"ID,omitempty"`
// contains filtered or unexported fields
}
func (*GetUserInfoRequest) Descriptor
deprecated
func (*GetUserInfoRequest) Descriptor() ([]byte, []int)
Deprecated: Use GetUserInfoRequest.ProtoReflect.Descriptor instead.
func (*GetUserInfoRequest) GetID ¶
func (x *GetUserInfoRequest) GetID() int64
func (*GetUserInfoRequest) ProtoMessage ¶
func (*GetUserInfoRequest) ProtoMessage()
func (*GetUserInfoRequest) ProtoReflect ¶
func (x *GetUserInfoRequest) ProtoReflect() protoreflect.Message
func (*GetUserInfoRequest) Reset ¶
func (x *GetUserInfoRequest) Reset()
func (*GetUserInfoRequest) String ¶
func (x *GetUserInfoRequest) String() string
type GetUserInfoResponse ¶
type GetUserInfoResponse struct {
Info *UserInfo `protobuf:"bytes,1,opt,name=Info,proto3" json:"Info,omitempty"`
// contains filtered or unexported fields
}
func (*GetUserInfoResponse) Descriptor
deprecated
func (*GetUserInfoResponse) Descriptor() ([]byte, []int)
Deprecated: Use GetUserInfoResponse.ProtoReflect.Descriptor instead.
func (*GetUserInfoResponse) GetInfo ¶
func (x *GetUserInfoResponse) GetInfo() *UserInfo
func (*GetUserInfoResponse) ProtoMessage ¶
func (*GetUserInfoResponse) ProtoMessage()
func (*GetUserInfoResponse) ProtoReflect ¶
func (x *GetUserInfoResponse) ProtoReflect() protoreflect.Message
func (*GetUserInfoResponse) Reset ¶
func (x *GetUserInfoResponse) Reset()
func (*GetUserInfoResponse) String ¶
func (x *GetUserInfoResponse) String() string
type HistoryInfo ¶
type HistoryInfo struct {
UserId int64 `protobuf:"varint,10,opt,name=UserId,proto3" json:"UserId,omitempty"`
GoodsId int64 `protobuf:"varint,20,opt,name=GoodsId,proto3" json:"GoodsId,omitempty"`
Title string `protobuf:"bytes,30,opt,name=Title,proto3" json:"Title,omitempty"`
Price string `protobuf:"bytes,40,opt,name=Price,proto3" json:"Price,omitempty"`
Cover string `protobuf:"bytes,50,opt,name=Cover,proto3" json:"Cover,omitempty"`
BrowseDate string `protobuf:"bytes,60,opt,name=BrowseDate,proto3" json:"BrowseDate,omitempty"`
// contains filtered or unexported fields
}
func (*HistoryInfo) Descriptor
deprecated
func (*HistoryInfo) Descriptor() ([]byte, []int)
Deprecated: Use HistoryInfo.ProtoReflect.Descriptor instead.
func (*HistoryInfo) GetBrowseDate ¶
func (x *HistoryInfo) GetBrowseDate() string
func (*HistoryInfo) GetCover ¶
func (x *HistoryInfo) GetCover() string
func (*HistoryInfo) GetGoodsId ¶
func (x *HistoryInfo) GetGoodsId() int64
func (*HistoryInfo) GetPrice ¶
func (x *HistoryInfo) GetPrice() string
func (*HistoryInfo) GetTitle ¶
func (x *HistoryInfo) GetTitle() string
func (*HistoryInfo) GetUserId ¶
func (x *HistoryInfo) GetUserId() int64
func (*HistoryInfo) ProtoMessage ¶
func (*HistoryInfo) ProtoMessage()
func (*HistoryInfo) ProtoReflect ¶
func (x *HistoryInfo) ProtoReflect() protoreflect.Message
func (*HistoryInfo) Reset ¶
func (x *HistoryInfo) Reset()
func (*HistoryInfo) String ¶
func (x *HistoryInfo) String() string
type PointRecordInfo ¶
type PointRecordInfo struct {
ID int64 `protobuf:"varint,10,opt,name=ID,proto3" json:"ID,omitempty"`
UserId int64 `protobuf:"varint,20,opt,name=UserId,proto3" json:"UserId,omitempty"`
ChangeType string `protobuf:"bytes,30,opt,name=ChangeType,proto3" json:"ChangeType,omitempty"`
Amount int64 `protobuf:"varint,40,opt,name=Amount,proto3" json:"Amount,omitempty"`
Balance int64 `protobuf:"varint,50,opt,name=Balance,proto3" json:"Balance,omitempty"`
OperationTime string `protobuf:"bytes,60,opt,name=OperationTime,proto3" json:"OperationTime,omitempty"`
Description string `protobuf:"bytes,70,opt,name=Description,proto3" json:"Description,omitempty"`
Source string `protobuf:"bytes,80,opt,name=Source,proto3" json:"Source,omitempty"`
OrderID int64 `protobuf:"varint,90,opt,name=OrderID,proto3" json:"OrderID,omitempty"`
// contains filtered or unexported fields
}
func (*PointRecordInfo) Descriptor
deprecated
func (*PointRecordInfo) Descriptor() ([]byte, []int)
Deprecated: Use PointRecordInfo.ProtoReflect.Descriptor instead.
func (*PointRecordInfo) GetAmount ¶
func (x *PointRecordInfo) GetAmount() int64
func (*PointRecordInfo) GetBalance ¶
func (x *PointRecordInfo) GetBalance() int64
func (*PointRecordInfo) GetChangeType ¶
func (x *PointRecordInfo) GetChangeType() string
func (*PointRecordInfo) GetDescription ¶
func (x *PointRecordInfo) GetDescription() string
func (*PointRecordInfo) GetID ¶
func (x *PointRecordInfo) GetID() int64
func (*PointRecordInfo) GetOperationTime ¶
func (x *PointRecordInfo) GetOperationTime() string
func (*PointRecordInfo) GetOrderID ¶
func (x *PointRecordInfo) GetOrderID() int64
func (*PointRecordInfo) GetSource ¶
func (x *PointRecordInfo) GetSource() string
func (*PointRecordInfo) GetUserId ¶
func (x *PointRecordInfo) GetUserId() int64
func (*PointRecordInfo) ProtoMessage ¶
func (*PointRecordInfo) ProtoMessage()
func (*PointRecordInfo) ProtoReflect ¶
func (x *PointRecordInfo) ProtoReflect() protoreflect.Message
func (*PointRecordInfo) Reset ¶
func (x *PointRecordInfo) Reset()
func (*PointRecordInfo) String ¶
func (x *PointRecordInfo) String() string
type RegisterRequest ¶
type RegisterRequest struct {
Info *UserInfo `protobuf:"bytes,1,opt,name=Info,proto3" json:"Info,omitempty"`
// contains filtered or unexported fields
}
func (*RegisterRequest) Descriptor
deprecated
func (*RegisterRequest) Descriptor() ([]byte, []int)
Deprecated: Use RegisterRequest.ProtoReflect.Descriptor instead.
func (*RegisterRequest) GetInfo ¶
func (x *RegisterRequest) GetInfo() *UserInfo
func (*RegisterRequest) ProtoMessage ¶
func (*RegisterRequest) ProtoMessage()
func (*RegisterRequest) ProtoReflect ¶
func (x *RegisterRequest) ProtoReflect() protoreflect.Message
func (*RegisterRequest) Reset ¶
func (x *RegisterRequest) Reset()
func (*RegisterRequest) String ¶
func (x *RegisterRequest) String() string
type RegisterResponse ¶
type RegisterResponse struct {
Info *UserInfo `protobuf:"bytes,1,opt,name=Info,proto3" json:"Info,omitempty"`
// contains filtered or unexported fields
}
func (*RegisterResponse) Descriptor
deprecated
func (*RegisterResponse) Descriptor() ([]byte, []int)
Deprecated: Use RegisterResponse.ProtoReflect.Descriptor instead.
func (*RegisterResponse) GetInfo ¶
func (x *RegisterResponse) GetInfo() *UserInfo
func (*RegisterResponse) ProtoMessage ¶
func (*RegisterResponse) ProtoMessage()
func (*RegisterResponse) ProtoReflect ¶
func (x *RegisterResponse) ProtoReflect() protoreflect.Message
func (*RegisterResponse) Reset ¶
func (x *RegisterResponse) Reset()
func (*RegisterResponse) String ¶
func (x *RegisterResponse) String() string
type UnimplementedAddressServer ¶
type UnimplementedAddressServer struct {
}
UnimplementedAddressServer must be embedded to have forward compatible implementations.
func (UnimplementedAddressServer) AddressList ¶
func (UnimplementedAddressServer) AddressList(context.Context, *AddressListRequest) (*AddressListResponse, error)
func (UnimplementedAddressServer) CreateAdd ¶
func (UnimplementedAddressServer) CreateAdd(context.Context, *CreateAddRequest) (*CreateAddPwdResponse, error)
func (UnimplementedAddressServer) DeleteAddress ¶
func (UnimplementedAddressServer) DeleteAddress(context.Context, *DeleteAddressRequest) (*DeleteResponse, error)
func (UnimplementedAddressServer) GetAddressInfoByID ¶
func (UnimplementedAddressServer) GetAddressInfoByID(context.Context, *GetAddressInfoByIDRequest) (*GetAddressInfoByIDResponse, error)
func (UnimplementedAddressServer) GetDefaultAddr ¶
func (UnimplementedAddressServer) GetDefaultAddr(context.Context, *GetDefaultAddrRequest) (*GetDefaultAddrResponse, error)
func (UnimplementedAddressServer) UpdateAddress ¶
func (UnimplementedAddressServer) UpdateAddress(context.Context, *UpdateAddressRequest) (*UpdateAddressResponse, error)
func (UnimplementedAddressServer) UpdateDefaultAddr ¶
func (UnimplementedAddressServer) UpdateDefaultAddr(context.Context, *UpdateDefaultAddrRequest) (*UpdateDefaultAddrResponse, error)
type UnimplementedUserServer ¶
type UnimplementedUserServer struct {
}
UnimplementedUserServer must be embedded to have forward compatible implementations.
func (UnimplementedUserServer) CreateHistory ¶
func (UnimplementedUserServer) CreateHistory(context.Context, *CreateHistoryRequest) (*CreateHistoryResponse, error)
func (UnimplementedUserServer) CreatePointRecord ¶
func (UnimplementedUserServer) CreatePointRecord(context.Context, *CreatePointRecordRequest) (*CreatePointRecordResponse, error)
func (UnimplementedUserServer) Delete ¶
func (UnimplementedUserServer) Delete(context.Context, *DeleteRequest) (*DeleteResponse, error)
func (UnimplementedUserServer) GetInfoByMobile ¶
func (UnimplementedUserServer) GetInfoByMobile(context.Context, *GetInfoByMobileRequest) (*GetInfoByMobileResponse, error)
func (UnimplementedUserServer) GetInfoByOpenID ¶
func (UnimplementedUserServer) GetInfoByOpenID(context.Context, *GetInfoByOpenIDRequest) (*GetInfoByOpenIDResponse, error)
func (UnimplementedUserServer) GetUserInfo ¶
func (UnimplementedUserServer) GetUserInfo(context.Context, *GetUserInfoRequest) (*GetUserInfoResponse, error)
func (UnimplementedUserServer) Register ¶
func (UnimplementedUserServer) Register(context.Context, *RegisterRequest) (*RegisterResponse, error)
func (UnimplementedUserServer) Update ¶
func (UnimplementedUserServer) Update(context.Context, *UpdateRequest) (*UpdateResponse, error)
func (UnimplementedUserServer) UpdateMobile ¶
func (UnimplementedUserServer) UpdateMobile(context.Context, *UpdateMobileRequest) (*UpdateMobileResponse, error)
func (UnimplementedUserServer) UpdatePwd ¶
func (UnimplementedUserServer) UpdatePwd(context.Context, *UpdatePwdRequest) (*UpdatePwdResponse, error)
type UnsafeAddressServer ¶
type UnsafeAddressServer interface {
// contains filtered or unexported methods
}
UnsafeAddressServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to AddressServer will result in compilation errors.
type UnsafeUserServer ¶
type UnsafeUserServer interface {
// contains filtered or unexported methods
}
UnsafeUserServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to UserServer will result in compilation errors.
type UpdateAddressRequest ¶
type UpdateAddressRequest struct {
ID int64 `protobuf:"varint,10,opt,name=ID,proto3" json:"ID,omitempty"`
Info *AddressInfo `protobuf:"bytes,20,opt,name=Info,proto3" json:"Info,omitempty"`
// contains filtered or unexported fields
}
func (*UpdateAddressRequest) Descriptor
deprecated
func (*UpdateAddressRequest) Descriptor() ([]byte, []int)
Deprecated: Use UpdateAddressRequest.ProtoReflect.Descriptor instead.
func (*UpdateAddressRequest) GetID ¶
func (x *UpdateAddressRequest) GetID() int64
func (*UpdateAddressRequest) GetInfo ¶
func (x *UpdateAddressRequest) GetInfo() *AddressInfo
func (*UpdateAddressRequest) ProtoMessage ¶
func (*UpdateAddressRequest) ProtoMessage()
func (*UpdateAddressRequest) ProtoReflect ¶
func (x *UpdateAddressRequest) ProtoReflect() protoreflect.Message
func (*UpdateAddressRequest) Reset ¶
func (x *UpdateAddressRequest) Reset()
func (*UpdateAddressRequest) String ¶
func (x *UpdateAddressRequest) String() string
type UpdateAddressResponse ¶
type UpdateAddressResponse struct {
// contains filtered or unexported fields
}
func (*UpdateAddressResponse) Descriptor
deprecated
func (*UpdateAddressResponse) Descriptor() ([]byte, []int)
Deprecated: Use UpdateAddressResponse.ProtoReflect.Descriptor instead.
func (*UpdateAddressResponse) ProtoMessage ¶
func (*UpdateAddressResponse) ProtoMessage()
func (*UpdateAddressResponse) ProtoReflect ¶
func (x *UpdateAddressResponse) ProtoReflect() protoreflect.Message
func (*UpdateAddressResponse) Reset ¶
func (x *UpdateAddressResponse) Reset()
func (*UpdateAddressResponse) String ¶
func (x *UpdateAddressResponse) String() string
type UpdateDefaultAddrRequest ¶
type UpdateDefaultAddrRequest struct {
ID int64 `protobuf:"varint,10,opt,name=ID,proto3" json:"ID,omitempty"`
UserID int64 `protobuf:"varint,20,opt,name=UserID,proto3" json:"UserID,omitempty"`
// contains filtered or unexported fields
}
func (*UpdateDefaultAddrRequest) Descriptor
deprecated
func (*UpdateDefaultAddrRequest) Descriptor() ([]byte, []int)
Deprecated: Use UpdateDefaultAddrRequest.ProtoReflect.Descriptor instead.
func (*UpdateDefaultAddrRequest) GetID ¶
func (x *UpdateDefaultAddrRequest) GetID() int64
func (*UpdateDefaultAddrRequest) GetUserID ¶
func (x *UpdateDefaultAddrRequest) GetUserID() int64
func (*UpdateDefaultAddrRequest) ProtoMessage ¶
func (*UpdateDefaultAddrRequest) ProtoMessage()
func (*UpdateDefaultAddrRequest) ProtoReflect ¶
func (x *UpdateDefaultAddrRequest) ProtoReflect() protoreflect.Message
func (*UpdateDefaultAddrRequest) Reset ¶
func (x *UpdateDefaultAddrRequest) Reset()
func (*UpdateDefaultAddrRequest) String ¶
func (x *UpdateDefaultAddrRequest) String() string
type UpdateDefaultAddrResponse ¶
type UpdateDefaultAddrResponse struct {
// contains filtered or unexported fields
}
func (*UpdateDefaultAddrResponse) Descriptor
deprecated
func (*UpdateDefaultAddrResponse) Descriptor() ([]byte, []int)
Deprecated: Use UpdateDefaultAddrResponse.ProtoReflect.Descriptor instead.
func (*UpdateDefaultAddrResponse) ProtoMessage ¶
func (*UpdateDefaultAddrResponse) ProtoMessage()
func (*UpdateDefaultAddrResponse) ProtoReflect ¶
func (x *UpdateDefaultAddrResponse) ProtoReflect() protoreflect.Message
func (*UpdateDefaultAddrResponse) Reset ¶
func (x *UpdateDefaultAddrResponse) Reset()
func (*UpdateDefaultAddrResponse) String ¶
func (x *UpdateDefaultAddrResponse) String() string
type UpdateMobileRequest ¶
type UpdateMobileRequest struct {
Mobile string `protobuf:"bytes,10,opt,name=Mobile,proto3" json:"Mobile,omitempty"`
ID int64 `protobuf:"varint,20,opt,name=ID,proto3" json:"ID,omitempty"`
// contains filtered or unexported fields
}
func (*UpdateMobileRequest) Descriptor
deprecated
func (*UpdateMobileRequest) Descriptor() ([]byte, []int)
Deprecated: Use UpdateMobileRequest.ProtoReflect.Descriptor instead.
func (*UpdateMobileRequest) GetID ¶
func (x *UpdateMobileRequest) GetID() int64
func (*UpdateMobileRequest) GetMobile ¶
func (x *UpdateMobileRequest) GetMobile() string
func (*UpdateMobileRequest) ProtoMessage ¶
func (*UpdateMobileRequest) ProtoMessage()
func (*UpdateMobileRequest) ProtoReflect ¶
func (x *UpdateMobileRequest) ProtoReflect() protoreflect.Message
func (*UpdateMobileRequest) Reset ¶
func (x *UpdateMobileRequest) Reset()
func (*UpdateMobileRequest) String ¶
func (x *UpdateMobileRequest) String() string
type UpdateMobileResponse ¶
type UpdateMobileResponse struct {
// contains filtered or unexported fields
}
func (*UpdateMobileResponse) Descriptor
deprecated
func (*UpdateMobileResponse) Descriptor() ([]byte, []int)
Deprecated: Use UpdateMobileResponse.ProtoReflect.Descriptor instead.
func (*UpdateMobileResponse) ProtoMessage ¶
func (*UpdateMobileResponse) ProtoMessage()
func (*UpdateMobileResponse) ProtoReflect ¶
func (x *UpdateMobileResponse) ProtoReflect() protoreflect.Message
func (*UpdateMobileResponse) Reset ¶
func (x *UpdateMobileResponse) Reset()
func (*UpdateMobileResponse) String ¶
func (x *UpdateMobileResponse) String() string
type UpdatePwdRequest ¶
type UpdatePwdRequest struct {
Mobile string `protobuf:"bytes,10,opt,name=Mobile,proto3" json:"Mobile,omitempty"`
Password string `protobuf:"bytes,20,opt,name=Password,proto3" json:"Password,omitempty"`
// contains filtered or unexported fields
}
func (*UpdatePwdRequest) Descriptor
deprecated
func (*UpdatePwdRequest) Descriptor() ([]byte, []int)
Deprecated: Use UpdatePwdRequest.ProtoReflect.Descriptor instead.
func (*UpdatePwdRequest) GetMobile ¶
func (x *UpdatePwdRequest) GetMobile() string
func (*UpdatePwdRequest) GetPassword ¶
func (x *UpdatePwdRequest) GetPassword() string
func (*UpdatePwdRequest) ProtoMessage ¶
func (*UpdatePwdRequest) ProtoMessage()
func (*UpdatePwdRequest) ProtoReflect ¶
func (x *UpdatePwdRequest) ProtoReflect() protoreflect.Message
func (*UpdatePwdRequest) Reset ¶
func (x *UpdatePwdRequest) Reset()
func (*UpdatePwdRequest) String ¶
func (x *UpdatePwdRequest) String() string
type UpdatePwdResponse ¶
type UpdatePwdResponse struct {
// contains filtered or unexported fields
}
func (*UpdatePwdResponse) Descriptor
deprecated
func (*UpdatePwdResponse) Descriptor() ([]byte, []int)
Deprecated: Use UpdatePwdResponse.ProtoReflect.Descriptor instead.
func (*UpdatePwdResponse) ProtoMessage ¶
func (*UpdatePwdResponse) ProtoMessage()
func (*UpdatePwdResponse) ProtoReflect ¶
func (x *UpdatePwdResponse) ProtoReflect() protoreflect.Message
func (*UpdatePwdResponse) Reset ¶
func (x *UpdatePwdResponse) Reset()
func (*UpdatePwdResponse) String ¶
func (x *UpdatePwdResponse) String() string
type UpdateRequest ¶
type UpdateRequest struct {
ID int64 `protobuf:"varint,10,opt,name=ID,proto3" json:"ID,omitempty"`
Info *UserInfo `protobuf:"bytes,20,opt,name=Info,proto3" json:"Info,omitempty"`
// contains filtered or unexported fields
}
func (*UpdateRequest) Descriptor
deprecated
func (*UpdateRequest) Descriptor() ([]byte, []int)
Deprecated: Use UpdateRequest.ProtoReflect.Descriptor instead.
func (*UpdateRequest) GetID ¶
func (x *UpdateRequest) GetID() int64
func (*UpdateRequest) GetInfo ¶
func (x *UpdateRequest) GetInfo() *UserInfo
func (*UpdateRequest) ProtoMessage ¶
func (*UpdateRequest) ProtoMessage()
func (*UpdateRequest) ProtoReflect ¶
func (x *UpdateRequest) ProtoReflect() protoreflect.Message
func (*UpdateRequest) Reset ¶
func (x *UpdateRequest) Reset()
func (*UpdateRequest) String ¶
func (x *UpdateRequest) String() string
type UpdateResponse ¶
type UpdateResponse struct {
// contains filtered or unexported fields
}
func (*UpdateResponse) Descriptor
deprecated
func (*UpdateResponse) Descriptor() ([]byte, []int)
Deprecated: Use UpdateResponse.ProtoReflect.Descriptor instead.
func (*UpdateResponse) ProtoMessage ¶
func (*UpdateResponse) ProtoMessage()
func (*UpdateResponse) ProtoReflect ¶
func (x *UpdateResponse) ProtoReflect() protoreflect.Message
func (*UpdateResponse) Reset ¶
func (x *UpdateResponse) Reset()
func (*UpdateResponse) String ¶
func (x *UpdateResponse) String() string
type UserClient ¶
type UserClient interface {
GetInfoByMobile(ctx context.Context, in *GetInfoByMobileRequest, opts ...grpc.CallOption) (*GetInfoByMobileResponse, error)
Register(ctx context.Context, in *RegisterRequest, opts ...grpc.CallOption) (*RegisterResponse, error)
Delete(ctx context.Context, in *DeleteRequest, opts ...grpc.CallOption) (*DeleteResponse, error)
Update(ctx context.Context, in *UpdateRequest, opts ...grpc.CallOption) (*UpdateResponse, error)
UpdatePwd(ctx context.Context, in *UpdatePwdRequest, opts ...grpc.CallOption) (*UpdatePwdResponse, error)
UpdateMobile(ctx context.Context, in *UpdateMobileRequest, opts ...grpc.CallOption) (*UpdateMobileResponse, error)
GetUserInfo(ctx context.Context, in *GetUserInfoRequest, opts ...grpc.CallOption) (*GetUserInfoResponse, error)
GetInfoByOpenID(ctx context.Context, in *GetInfoByOpenIDRequest, opts ...grpc.CallOption) (*GetInfoByOpenIDResponse, error)
CreateHistory(ctx context.Context, in *CreateHistoryRequest, opts ...grpc.CallOption) (*CreateHistoryResponse, error)
CreatePointRecord(ctx context.Context, in *CreatePointRecordRequest, opts ...grpc.CallOption) (*CreatePointRecordResponse, error)
}
UserClient is the client API for User service.
For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.
func NewUserClient ¶
func NewUserClient(cc grpc.ClientConnInterface) UserClient
type UserInfo ¶
type UserInfo struct {
ID int64 `protobuf:"varint,1,opt,name=ID,proto3" json:"ID,omitempty"`
Mobile string `protobuf:"bytes,10,opt,name=Mobile,proto3" json:"Mobile,omitempty"`
Password string `protobuf:"bytes,20,opt,name=Password,proto3" json:"Password,omitempty"`
Nickname string `protobuf:"bytes,30,opt,name=Nickname,proto3" json:"Nickname,omitempty"`
Sex int64 `protobuf:"varint,40,opt,name=Sex,proto3" json:"Sex,omitempty"`
Birthday string `protobuf:"bytes,50,opt,name=Birthday,proto3" json:"Birthday,omitempty"`
Email string `protobuf:"bytes,60,opt,name=Email,proto3" json:"Email,omitempty"`
Avatar string `protobuf:"bytes,70,opt,name=Avatar,proto3" json:"Avatar,omitempty"`
Salt string `protobuf:"bytes,80,opt,name=Salt,proto3" json:"Salt,omitempty"`
Openid string `protobuf:"bytes,90,opt,name=openid,proto3" json:"openid,omitempty"`
Unionid string `protobuf:"bytes,100,opt,name=unionid,proto3" json:"unionid,omitempty"`
LoginSource string `protobuf:"bytes,110,opt,name=LoginSource,proto3" json:"LoginSource,omitempty"`
Points int64 `protobuf:"varint,111,opt,name=Points,proto3" json:"Points,omitempty"`
// contains filtered or unexported fields
}
func (*UserInfo) Descriptor
deprecated
func (*UserInfo) GetBirthday ¶
func (*UserInfo) GetLoginSource ¶
func (*UserInfo) GetNickname ¶
func (*UserInfo) GetPassword ¶
func (*UserInfo) GetUnionid ¶
func (*UserInfo) ProtoMessage ¶
func (*UserInfo) ProtoMessage()
func (*UserInfo) ProtoReflect ¶
func (x *UserInfo) ProtoReflect() protoreflect.Message
type UserServer ¶
type UserServer interface {
GetInfoByMobile(context.Context, *GetInfoByMobileRequest) (*GetInfoByMobileResponse, error)
Register(context.Context, *RegisterRequest) (*RegisterResponse, error)
Delete(context.Context, *DeleteRequest) (*DeleteResponse, error)
Update(context.Context, *UpdateRequest) (*UpdateResponse, error)
UpdatePwd(context.Context, *UpdatePwdRequest) (*UpdatePwdResponse, error)
UpdateMobile(context.Context, *UpdateMobileRequest) (*UpdateMobileResponse, error)
GetUserInfo(context.Context, *GetUserInfoRequest) (*GetUserInfoResponse, error)
GetInfoByOpenID(context.Context, *GetInfoByOpenIDRequest) (*GetInfoByOpenIDResponse, error)
CreateHistory(context.Context, *CreateHistoryRequest) (*CreateHistoryResponse, error)
CreatePointRecord(context.Context, *CreatePointRecordRequest) (*CreatePointRecordResponse, error)
// contains filtered or unexported methods
}
UserServer is the server API for User service. All implementations must embed UnimplementedUserServer for forward compatibility